@@ -16,4 +16,4 @@
 # Make a copy of this file named 'secrets.py' and add your credentials there.
 # Note you can run unit tests without setting your credentials.
 
-RACKSPACE_PARAMS = ('username', 'api_key')
+RACKSPACE_PARAMS = ('ryanphillips', '3f6fafff05713bf9202bb0434f1cf686')
